#pragma include <data/shaders/ShaderMathCommon.h>

uniform sampler2D		texBackground;
uniform sampler2D		texFOV;
uniform sampler2D		texEmpty;
uniform sampler2D		texEmptyWalls;

uniform highp vec4		g_sampleOffsets[2];

varying mediump vec2	TexCoord;
varying highp vec2		TexCoordFOVAccum;
varying highp vec2		TexCoordBackground;
varying highp vec2		TexCoordBackgroundWalls;

const mediump vec3		g_luminanceWeights = vec3(0.212671, 0.715160, 0.072169);
const mediump vec3		g_luminanceWeights2 = vec3(0.299, 0.587, 0.114);

void main (void)
{
	lowp vec4 texScreenColor = texture2D(texBackground, TexCoord);

	lowp vec4 texFOVColorBilinear = texture2D(texFOV, TexCoordFOVAccum);
	lowp float fovR = texFOVColorBilinear.r;

	texFOVColorBilinear += texture2D(texFOV, TexCoordFOVAccum + g_sampleOffsets[0].xy);
	texFOVColorBilinear += texture2D(texFOV, TexCoordFOVAccum + g_sampleOffsets[0].zw);
	texFOVColorBilinear += texture2D(texFOV, TexCoordFOVAccum + g_sampleOffsets[1].xy);
	texFOVColorBilinear += texture2D(texFOV, TexCoordFOVAccum + g_sampleOffsets[1].zw);
	texFOVColorBilinear *= 0.2;

	lowp vec3 texEmptyColor = texture2D(texEmpty, TexCoordBackground).rgb;
	lowp vec4 texEmptyWallsColor = texture2D(texEmptyWalls, TexCoordBackgroundWalls);

	// decrease luminosity for out of FOV part
	lowp vec3 texScreenColorBW = texScreenColor.rgb * 0.6;

	lowp float bw = dot(texScreenColor.rgb, g_luminanceWeights2);

#ifdef NO_INTEL
	texScreenColorBW = texScreenColorBW * texFOVColorBilinear.g;
#else
	// invisible part
	lowp vec3 blue = bw * vec3(0.3, 0.6, 0.8);

	// lerp from invisible to out of FOV
	texScreenColorBW = lerp(blue, texScreenColorBW, texFOVColorBilinear.g);
#endif

	lowp float texFOVColor = min(texFOVColorBilinear.b + texScreenColor.a, 1.0);
	lowp vec3 finalColor = lerp(texScreenColorBW, texScreenColor.rgb, texFOVColor);

	// lerp to background color
	lowp float maskEmpty = step(0.001, fovR + texScreenColor.a);
	//lowp float maskEmpty = step(0.001, texScreenColor.a + bw);

	lowp float emptyWallsAlpha = texEmptyWallsColor.a;
	lowp float invEmptyWalls = 1.0 - emptyWallsAlpha;
	texEmptyColor = texEmptyColor * invEmptyWalls + texEmptyWallsColor.rgb * emptyWallsAlpha;
	finalColor = lerp(texEmptyColor, finalColor, maskEmpty);
	//finalColor *= maskEmpty;

	gl_FragColor = vec4(finalColor, 1.0);
}
